Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(363)

Unified Diff: content/browser/web_contents/aura/overscroll_navigation_overlay.h

Issue 880703002: Move ImageWindowDelegate to ui/aura_extra (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Updated a comment Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/web_contents/aura/overscroll_navigation_overlay.h
diff --git a/content/browser/web_contents/aura/overscroll_navigation_overlay.h b/content/browser/web_contents/aura/overscroll_navigation_overlay.h
index d65d374a848ab512a9246c0dc580c34fd6b0ce66..db9871c024981ff908b20bfd9b2ed1baddcc6eaa 100644
--- a/content/browser/web_contents/aura/overscroll_navigation_overlay.h
+++ b/content/browser/web_contents/aura/overscroll_navigation_overlay.h
@@ -13,10 +13,13 @@
struct ViewHostMsg_UpdateRect_Params;
+namespace aura_extra {
+class ImageWindowDelegate;
+}
+
namespace content {
class ImageLayerDelegate;
-class ImageWindowDelegate;
class OverscrollNavigationOverlayTest;
// When a history navigation is triggered at the end of an overscroll
@@ -43,10 +46,10 @@ class CONTENT_EXPORT OverscrollNavigationOverlay
// Sets the screenshot window and the delegate. This takes ownership of
// |window|.
// Note that ImageWindowDelegate manages its own lifetime, so this function
// does not take ownership of |delegate|.
void SetOverlayWindow(scoped_ptr<aura::Window> window,
- ImageWindowDelegate* delegate);
+ aura_extra::ImageWindowDelegate* delegate);
private:
friend class OverscrollNavigationOverlayTest;
@@ -96,7 +99,7 @@ class CONTENT_EXPORT OverscrollNavigationOverlay
// This is the WindowDelegate of |window_|. The delegate manages its own
// lifetime (destroys itself when |window_| is destroyed).
- ImageWindowDelegate* image_delegate_;
+ aura_extra::ImageWindowDelegate* image_delegate_;
bool loading_complete_;
bool received_paint_update_;
@@ -43,10 +46,10 @@ class CONTENT_EXPORT OverscrollNavigationOverlay
// Sets the screenshot window and the delegate. This takes ownership of
// |window|.
- // Note that ImageWindowDelegate manages its own lifetime, so this function
- // does not take ownership of |delegate|.
+ // Note that aura_extra::ImageWindowDelegate manages its own lifetime, so this
+ // function does not take ownership of |delegate|.
void SetOverlayWindow(scoped_ptr<aura::Window> window,

Powered by Google App Engine
This is Rietveld 408576698